Learn R Programming

AEenrich (version 1.1.1)

AEenrich-package: AEenrich: Adverse Event Enrichment Tests

Description

The count_cases function converts report-level data into aggregated data by grouping on specified covariates. Use count_cases to summarize adverse event reports into analysis-ready tables. See the GitHub home page at https://github.com/umich-biostatistics/AEenrich or run ?count_cases for examples.

Perform adverse event enrichment tests. The enrich function implements enrichment analysis for adverse event count data, which contain many zeros and ties. Two methods are provided: AEFisher, a modified Fisher’s exact test based on pre-selected significant adverse events, and AEKS, a modified Kolmogorov–Smirnov statistic. See the GitHub home page at https://github.com/umich-biostatistics/AEenrich or run ?enrich for examples.

Arguments

Author

Maintainer: Michael Kleinsasser mkleinsa@umich.edu

Authors:

See Also