Learn R Programming

AEenrich (version 1.1.1)

covid2: Covid Vaccine Adverse Event Data

Description

Adverse event data in the short format. Each row is a count of adverse events with the given name.

Usage

covid2

Arguments

Value

A data frame with the following columns:

DRUG_TYPE

Vaccine type

AE_NAME

Adverse event name

AEYes

Number of observations that have this adverse event

AENo

Number of observations that do not have this adverse event

AGE

Covariate

SEX

Covariate

Format

An object of class tbl_df (inherits from tbl, data.frame) with 2656 rows and 6 columns.