powered by
Adverse event data in the short format. Each row is a count of adverse events with the given name.
covid2
A data frame with the following columns:
Vaccine type
Adverse event name
Number of observations that have this adverse event
Number of observations that do not have this adverse event
Covariate
An object of class tbl_df (inherits from tbl, data.frame) with 2656 rows and 6 columns.
tbl_df
tbl
data.frame